@@ -9,7 +9,7 @@
 #
 package Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch;
 {
-  $Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch::VERSION = '0.005';
+  $Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch::VERSION = '0.006';
 }
 
 # ABSTRACT: Check that you're on the correct branch before release
@@ -78,7 +78,7 @@ Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch - Check that you're on the cor
 
 =head1 VERSION
 
-This document describes version 0.005 of Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch - released October 03, 2012 as part of Dist-Zilla-PluginBundle-Git-CheckFor.
+This document describes version 0.006 of Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch - released November 14, 2012 as part of Dist-Zilla-PluginBundle-Git-CheckFor.
 
 =head1 SYNOPSIS
 
@@ -152,6 +152,20 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Karen Etheridge L<ETHER|https://metacpan.org/author/ETHER>
+
+=item *
+
+Mike Doherty L<DOHERTY|https://metacpan.org/author/DOHERTY>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2012 by Chris Weyl.
